@@ -85,12 +85,12 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.7m',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.7.3/build/optimized/coverage.info',
- 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.7.3/build/optimized/lcov-report',
+ 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.7.4/build/optimized/coverage.info',
+ 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.7.4/build/optimized/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/builddir/build/BUILD/Python-3.7.3/Include',
+             '-I/builddir/build/BUILD/Python-3.7.4/Include',
  'CXX': 'g++ -pthread',
  'DESTDIRS': '/usr /usr/lib64 /usr/lib64/python3.7 '
              '/usr/lib64/python3.7/lib-dynload',
@@ -579,7 +579,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
- 'MAKESETUP': '/builddir/build/BUILD/Python-3.7.3/Modules/makesetup',
+ 'MAKESETUP': '/builddir/build/BUILD/Python-3.7.4/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
@@ -681,7 +681,7 @@ build_time_vars = {'ABIFLAGS': 'm',
                              '-D_GNU_SOURCE -fPIC -fwrapv -fprofile-use '
                              '-fprofile-correction -IObjects -IInclude '
                              '-IPython -I. '
-                             '-I/builddir/build/BUILD/Python-3.7.3/Include '
+                             '-I/builddir/build/BUILD/Python-3.7.4/Include '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare '
               '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2 -g -pipe -Wall '
@@ -741,7 +741,7 @@ build_time_vars = {'ABIFLAGS': 'm',
                    '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE '
                    '-fPIC -fwrapv -fprofile-use -fprofile-correction -IObjects '
                    '-IInclude -IPython -I. '
-                   '-I/builddir/build/BUILD/Python-3.7.3/Include '
+                   '-I/builddir/build/BUILD/Python-3.7.4/Include '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now  -g -Wl,-z,relro '
                     '-Wl,--as-needed  -Wl,-z,now '
@@ -749,7 +749,7 @@ build_time_vars = {'ABIFLAGS': 'm',
                     '-fuse-linker-plugin -ffat-lto-objects '
                     '-flto-partition=none -g',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/builddir/build/BUILD/Python-3.7.3/Include',
+                '-I/builddir/build/BUILD/Python-3.7.4/Include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now  -g',
  'PY_LDFLAGS_NODIST': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now '
@@ -789,7 +789,7 @@ build_time_vars = {'ABIFLAGS': 'm',
                         '-fstack-clash-protection -fcf-protection '
                         '-D_GNU_SOURCE -fPIC -fwrapv -fprofile-use '
                         '-fprofile-correction -IObjects -IInclude -IPython -I. '
-                        '-I/builddir/build/BUILD/Python-3.7.3/Include',
+                        '-I/builddir/build/BUILD/Python-3.7.4/Include',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -797,7 +797,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.3/build/optimized',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.4/build/optimized',
  'SCRIPTDIR': '/usr/lib64',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -825,8 +825,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-37m-x86_64-linux-gnu',
- 'SRCDIRS': 'Parser Objects Python Modules Programs',
- 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.7.3/Tools/gdb/libpython.py',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
+ 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.7.4/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -839,10 +839,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.3/build/optimized '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.4/build/optimized '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.3/build/optimized '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.4/build/optimized '
                './python /Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -851,10 +851,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3.7 '
-                '/builddir/build/BUILD/Python-3.7.3/Tools/scripts/update_file.py',
+                '/builddir/build/BUILD/Python-3.7.4/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.7',
- 'VPATH': '/builddir/build/BUILD/Python-3.7.3',
+ 'VPATH': '/builddir/build/BUILD/Python-3.7.4',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 1,
@@ -865,9 +865,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 1,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/builddir/build/BUILD/Python-3.7.3/build/optimized',
- 'abs_srcdir': '/builddir/build/BUILD/Python-3.7.3',
+ 'abs_builddir': '/builddir/build/BUILD/Python-3.7.4/build/optimized',
+ 'abs_srcdir': '/builddir/build/BUILD/Python-3.7.4',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/builddir/build/BUILD/Python-3.7.3'}
+ 'srcdir': '/builddir/build/BUILD/Python-3.7.4'}
